@@ -8,6 +8,21 @@ from DAQmxConfig import dot_h_file
 
 include_file = open(dot_h_file,'r') #Open NIDAQmx.h file
 
+# Try get the version of NIDAQmx
+preamble = []
+for line in include_file:
+    if line.startswith('/*'):
+        preamble.append(line)
+    else:
+        break
+
+for copyright_line in preamble:
+    if "Copyright" in copyright_line:
+        DAQmx_copyright_year = max(map(int, re.findall('\d\d\d\d', copyright_line)))
+        break
+else:
+    DAQmx_copyright_year = 2003
+
 # Regular expression to parse the #define line
 # Parse line like : #define PI 3.141592
 # The first group is the name of the constant
