@@ -105,9 +105,9 @@ class Task():
         doc = 'T.%s(%s) -> error.' %(name, ', '.join(arg_names[1:]))
         cmd = """def {0}(self, {1}):
         "{3}"
-        {2}(self, {1})"""
+        {2}(self.taskHandle, {1})"""
         exec(cmd.format(name, ', '.join(arg_names[1:]), function_name, doc))    
     del function_name, name, func, arg_names, doc
 
 
-del task_function_list
\ No newline at end of file
+del task_function_list
